pub struct GGLWEToGGSWKeyLayout {
pub n: Degree,
pub base2k: Base2K,
pub k: TorusPrecision,
pub rank: Rank,
pub dnum: Dnum,
pub dsize: Dsize,
}Fields
n: Degreebase2k: Base2Kk: TorusPrecisionrank: Rankdnum: Dnumdsize: DsizeTrait Implementations
Sourceimpl Clone for GGLWEToGGSWKeyLayout
impl Clone for GGLWEToGGSWKeyLayout
Sourcefn clone(&self) -> GGLWEToGGSWKeyLayout
fn clone(&self) -> GGLWEToGGSWKeyLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GGLWEToGGSWKeyLayout
impl Debug for GGLWEToGGSWKeyLayout
Sourceimpl DeclaredK for GGLWEToGGSWKeyLayout
impl DeclaredK for GGLWEToGGSWKeyLayout
fn k(&self) -> TorusPrecision
Sourceimpl GGLWEInfos for GGLWEToGGSWKeyLayout
impl GGLWEInfos for GGLWEToGGSWKeyLayout
Sourceimpl GLWEInfos for GGLWEToGGSWKeyLayout
impl GLWEInfos for GGLWEToGGSWKeyLayout
Sourcefn glwe_layout(&self) -> GLWELayout
fn glwe_layout(&self) -> GLWELayout
Returns a plain-data
GLWELayout snapshot of the current parameters.Sourceimpl LWEInfos for GGLWEToGGSWKeyLayout
impl LWEInfos for GGLWEToGGSWKeyLayout
Sourcefn n(&self) -> Degree
fn n(&self) -> Degree
Returns the LWE dimension, i.e. the number of mask elements (= GLWE ring degree N).
Sourcefn base2k(&self) -> Base2K
fn base2k(&self) -> Base2K
Returns the base-2-log of the limb width used for the RNS/CRT representation.
Sourcefn max_k(&self) -> TorusPrecision
fn max_k(&self) -> TorusPrecision
Returns the maximum torus precision representable with the current limb decomposition.
Sourcefn lwe_layout(&self) -> LWELayout
fn lwe_layout(&self) -> LWELayout
Returns a plain-data
LWELayout snapshot of the current parameters.Sourceimpl PartialEq for GGLWEToGGSWKeyLayout
impl PartialEq for GGLWEToGGSWKeyLayout
Sourcefn eq(&self, other: &GGLWEToGGSWKeyLayout) -> bool
fn eq(&self, other: &GGLWEToGGSWKeyLayout) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for GGLWEToGGSWKeyLayout
impl Eq for GGLWEToGGSWKeyLayout
impl StructuralPartialEq for GGLWEToGGSWKeyLayout