pub struct GLWEToLWEKeyLayout {
pub n: Degree,
pub base2k: Base2K,
pub k: TorusPrecision,
pub rank_in: Rank,
pub dnum: Dnum,
}Fields
n: Degreebase2k: Base2Kk: TorusPrecisionrank_in: Rankdnum: DnumTrait Implementations
Sourceimpl Clone for GLWEToLWEKeyLayout
impl Clone for GLWEToLWEKeyLayout
Sourcefn clone(&self) -> GLWEToLWEKeyLayout
fn clone(&self) -> GLWEToLWEKeyLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GLWEToLWEKeyLayout
impl Debug for GLWEToLWEKeyLayout
Sourceimpl DeclaredK for GLWEToLWEKeyLayout
impl DeclaredK for GLWEToLWEKeyLayout
fn k(&self) -> TorusPrecision
Sourceimpl GGLWEInfos for GLWEToLWEKeyLayout
impl GGLWEInfos for GLWEToLWEKeyLayout
Sourceimpl GLWEInfos for GLWEToLWEKeyLayout
impl GLWEInfos for GLWEToLWEKeyLayout
Sourcefn glwe_layout(&self) -> GLWELayout
fn glwe_layout(&self) -> GLWELayout
Returns a plain-data
GLWELayout snapshot of the current parameters.Sourceimpl LWEInfos for GLWEToLWEKeyLayout
impl LWEInfos for GLWEToLWEKeyLayout
Sourcefn n(&self) -> Degree
fn n(&self) -> Degree
Returns the LWE dimension, i.e. the number of mask elements (= GLWE ring degree N).
Sourcefn base2k(&self) -> Base2K
fn base2k(&self) -> Base2K
Returns the base-2-log of the limb width used for the RNS/CRT representation.
Sourcefn max_k(&self) -> TorusPrecision
fn max_k(&self) -> TorusPrecision
Returns the maximum torus precision representable with the current limb decomposition.
Sourcefn lwe_layout(&self) -> LWELayout
fn lwe_layout(&self) -> LWELayout
Returns a plain-data
LWELayout snapshot of the current parameters.Sourceimpl PartialEq for GLWEToLWEKeyLayout
impl PartialEq for GLWEToLWEKeyLayout
Sourcefn eq(&self, other: &GLWEToLWEKeyLayout) -> bool
fn eq(&self, other: &GLWEToLWEKeyLayout) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for GLWEToLWEKeyLayout
impl Eq for GLWEToLWEKeyLayout
impl StructuralPartialEq for GLWEToLWEKeyLayout