pub struct LWESwitchingKeyLayout {
pub n: Degree,
pub base2k: Base2K,
pub k: TorusPrecision,
pub dnum: Dnum,
}Fields
n: Degreebase2k: Base2Kk: TorusPrecisiondnum: DnumTrait Implementations
Sourceimpl Clone for LWESwitchingKeyLayout
impl Clone for LWESwitchingKeyLayout
Sourcefn clone(&self) -> LWESwitchingKeyLayout
fn clone(&self) -> LWESwitchingKeyLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LWESwitchingKeyLayout
impl Debug for LWESwitchingKeyLayout
Sourceimpl DeclaredK for LWESwitchingKeyLayout
impl DeclaredK for LWESwitchingKeyLayout
fn k(&self) -> TorusPrecision
Sourceimpl GGLWEInfos for LWESwitchingKeyLayout
impl GGLWEInfos for LWESwitchingKeyLayout
Sourceimpl GLWEInfos for LWESwitchingKeyLayout
impl GLWEInfos for LWESwitchingKeyLayout
Sourcefn glwe_layout(&self) -> GLWELayout
fn glwe_layout(&self) -> GLWELayout
Returns a plain-data
GLWELayout snapshot of the current parameters.Sourceimpl LWEInfos for LWESwitchingKeyLayout
impl LWEInfos for LWESwitchingKeyLayout
Sourcefn n(&self) -> Degree
fn n(&self) -> Degree
Returns the LWE dimension, i.e. the number of mask elements (= GLWE ring degree N).
Sourcefn base2k(&self) -> Base2K
fn base2k(&self) -> Base2K
Returns the base-2-log of the limb width used for the RNS/CRT representation.
Sourcefn max_k(&self) -> TorusPrecision
fn max_k(&self) -> TorusPrecision
Returns the maximum torus precision representable with the current limb decomposition.
Sourcefn lwe_layout(&self) -> LWELayout
fn lwe_layout(&self) -> LWELayout
Returns a plain-data
LWELayout snapshot of the current parameters.Sourceimpl PartialEq for LWESwitchingKeyLayout
impl PartialEq for LWESwitchingKeyLayout
Sourcefn eq(&self, other: &LWESwitchingKeyLayout) -> bool
fn eq(&self, other: &LWESwitchingKeyLayout) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for LWESwitchingKeyLayout
impl Eq for LWESwitchingKeyLayout
impl StructuralPartialEq for LWESwitchingKeyLayout