pub struct LWEToGLWEKeyLayout {
pub n: Degree,
pub base2k: Base2K,
pub k: TorusPrecision,
pub rank_out: Rank,
pub dnum: Dnum,
}Fields
n: Degreebase2k: Base2Kk: TorusPrecisionrank_out: Rankdnum: DnumTrait Implementations
Sourceimpl Clone for LWEToGLWEKeyLayout
impl Clone for LWEToGLWEKeyLayout
Sourcefn clone(&self) -> LWEToGLWEKeyLayout
fn clone(&self) -> LWEToGLWEKeyLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LWEToGLWEKeyLayout
impl Debug for LWEToGLWEKeyLayout
Sourceimpl DeclaredK for LWEToGLWEKeyLayout
impl DeclaredK for LWEToGLWEKeyLayout
fn k(&self) -> TorusPrecision
Sourceimpl GGLWEInfos for LWEToGLWEKeyLayout
impl GGLWEInfos for LWEToGLWEKeyLayout
Sourceimpl GLWEInfos for LWEToGLWEKeyLayout
impl GLWEInfos for LWEToGLWEKeyLayout
Sourcefn glwe_layout(&self) -> GLWELayout
fn glwe_layout(&self) -> GLWELayout
Returns a plain-data
GLWELayout snapshot of the current parameters.Sourceimpl LWEInfos for LWEToGLWEKeyLayout
impl LWEInfos for LWEToGLWEKeyLayout
Sourcefn base2k(&self) -> Base2K
fn base2k(&self) -> Base2K
Returns the base-2-log of the limb width used for the RNS/CRT representation.
Sourcefn n(&self) -> Degree
fn n(&self) -> Degree
Returns the LWE dimension, i.e. the number of mask elements (= GLWE ring degree N).
Sourcefn max_k(&self) -> TorusPrecision
fn max_k(&self) -> TorusPrecision
Returns the maximum torus precision representable with the current limb decomposition.
Sourcefn lwe_layout(&self) -> LWELayout
fn lwe_layout(&self) -> LWELayout
Returns a plain-data
LWELayout snapshot of the current parameters.Sourceimpl PartialEq for LWEToGLWEKeyLayout
impl PartialEq for LWEToGLWEKeyLayout
Sourcefn eq(&self, other: &LWEToGLWEKeyLayout) -> bool
fn eq(&self, other: &LWEToGLWEKeyLayout) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for LWEToGLWEKeyLayout
impl Eq for LWEToGLWEKeyLayout
impl StructuralPartialEq for LWEToGLWEKeyLayout